- Fix bug `#6`_: `TimeSpan.overlaps <xoutil.datetime.TimeSpan.overlaps>`:meth:
  was incorrectly defined.

- Fix bug `#5`_: `~xoutil.datetime.TimeSpan`:class: can't have a `union`
  method.


.. _#5: https://gitlab.lahavane.com/merchise/xoutil/issues/5
.. _#6: https://gitlab.lahavane.com/merchise/xoutil/issues/6
